@@ -20,11 +20,4 @@
   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-extern bool		forceGifs;
-extern char*		texFile;
-extern char*		texOption;
-extern char*		texPackages[];
-extern int		numTexPackages;
-extern char*		texTitle;
-
 void makeGifs(const char *dir, const char *gifdb);
